#[repr(transparent)]pub struct m512(pub __m512);Expand description
The data for a 512-bit AVX-512 register of sixteen f32 lanes.
- This is very similar to having
[f32; 16]. The main difference is that it’s aligned to 64 instead of just 4, and of course you can perform various intrinsic operations on it.
Tuple Fields
0: __m512Implementations
Sourceimpl m512
impl m512
Sourcepub fn to_array(self) -> [f32; 16]
pub fn to_array(self) -> [f32; 16]
Transmutes the m512 to an array.
Same as m.into(), just lets you be more explicit about what’s happening.
Sourcepub fn from_array(f: [f32; 16]) -> Self
pub fn from_array(f: [f32; 16]) -> Self
Transmutes an array into m512.
Same as m512::from(arr), it just lets you be more explicit about what’s
happening.
Sourcepub fn to_bits(self) -> [u32; 16]
pub fn to_bits(self) -> [u32; 16]
Converts into the bit patterns of these floats ([u32;16]).
Like f32::to_bits, but all sixteen lanes at once.
Sourcepub fn from_bits(bits: [u32; 16]) -> Self
pub fn from_bits(bits: [u32; 16]) -> Self
Converts from the bit patterns of these floats ([u32;16]).
Like f32::from_bits, but all sixteen lanes at once.