#[repr(transparent)]pub struct m512i(pub __m512i);Expand description
The data for a 512-bit AVX-512 register of integer data.
- The exact layout to view the type as depends on the operation used.
FromandIntoimpls are provided for all the relevant signed integer array types.- Formatting impls print as sixteen
i32values just because they have to pick something. If you want an alternative you can turn it into an array and print as you like.
Tuple Fields
0: __m512iImplementations
Sourceimpl m512i
impl m512i
Sourcepub fn to_array(self) -> [i32; 16]
pub fn to_array(self) -> [i32; 16]
Transmutes the m512i to an array.
Same as m.into(), just lets you be more explicit about what’s happening.
Sourcepub fn from_array(f: [i32; 16]) -> Self
pub fn from_array(f: [i32; 16]) -> Self
Transmutes an array into m512i.
Same as m512i::from(arr), it just lets you be more explicit about what’s
happening.
Sourcepub fn to_bits(self) -> [i32; 16]
pub fn to_bits(self) -> [i32; 16]
Converts into the bit patterns of these doubles ([u64;8]).
Like f64::to_bits, but all eight lanes at once.
Sourcepub fn from_bits(bits: [i32; 16]) -> Self
pub fn from_bits(bits: [i32; 16]) -> Self
Converts from the bit patterns of these doubles ([u64;8]).
Like f64::from_bits, but all eight lanes at once.